"use strict";
Object.defineProperty(exports, Symbol.toStringTag, { value: "Module" });
const path = require("path");
const WebSocket = require("ws");
const fs = require("fs");
const olog = console.log;
const oerror = console.error;
const sendLog = (level = "info", message, data, error) => {
  if (process.env.TUZI_ENV === "app") {
    olog(
      `robotUtilLog-${JSON.stringify({ level, time: Date.now(), message, data, error })}`
    );
  }
};
const sendStepLog = (message) => {
  if (process.env.TUZI_ENV === "app") {
    if (process.send) {
      process.send({ type: "step", data: message });
    }
  }
};
function typeToCode(inputItem) {
  if (inputItem.type === "string") {
    return `String(\`${inputItem.value ?? ""}\`)`;
  } else if (inputItem.type === "number") {
    return `Number(String(\`${inputItem.value ?? ""}\`))`;
  } else if (inputItem.type === "boolean") {
    return `String(\`${inputItem.value ?? ""}\`).toLowerCase() == 'true'`;
  } else if (inputItem.type === "object") {
    if (!inputItem.enableExpression) {
      return `Number(String(\`${inputItem.value ?? ""}\`))`;
    }
    return `${inputItem.value ?? ""}`;
  }
  return "";
}
function getCurApp() {
  return curApp;
}
function getTuziAppInfo() {
  return _tuziAppInfo;
}
function flowModuleImport(appDir, moduleName) {
  const module2 = path.join(appDir, moduleName);
  return require(module2);
}
let messageId = 0;
function invokeApi(method, params) {
  return new Promise((resolve, reject) => {
    const id = ++messageId;
    const ws = new WebSocket.WebSocket(`ws://localhost:4046`);
    ws.on("open", () => {
      ws.send(JSON.stringify({ id, appId: curApp.APP_ID, method, params }));
      ws.once("message", (data) => {
        const res = JSON.parse(data.toString());
        if (res.code === 1) {
          resolve(res.result);
        } else {
          reject(new Error(res.result));
        }
        ws.close();
      });
    });
    ws.on("error", (error) => {
      reject(error);
    });
  });
}
Date.prototype.Format = function(fmt) {
  fmt = fmt || "yyyy-MM-dd hh:mm:ss";
  var o = {
    "M+": this.getMonth() + 1,
    //月份
    "d+": this.getDate(),
    //日
    "h+": this.getHours(),
    //小时
    "m+": this.getMinutes(),
    //分
    "s+": this.getSeconds(),
    //秒
    "q+": Math.floor((this.getMonth() + 3) / 3),
    //季度
    S: this.getMilliseconds()
    //毫秒
  };
  if (/(y+)/.test(fmt))
    fmt = fmt.replace(RegExp.$1, (this.getFullYear() + "").substr(4 - RegExp.$1.length));
  for (var k in o)
    if (new RegExp("(" + k + ")").test(fmt))
      fmt = fmt.replace(
        RegExp.$1,
        // @ts-ignore
        RegExp.$1.length == 1 ? o[k] : ("00" + o[k]).substr(("" + o[k]).length)
      );
  return fmt;
};
function setLogFile(filePath) {
  const logFileWriteStream = fs.createWriteStream(filePath);
  const levelMap = {
    debug: "调试",
    info: "信息",
    warn: "警告",
    error: "错误",
    fatalError: "致命"
  };
  function log(level, _block, ...args) {
    const message = args.join(" ");
    const levelStr = levelMap[level];
    const content = (
      // @ts-ignore
      `[${levelStr}] [${_block.flowName}:(行: ${_block.blockLine})] [${(/* @__PURE__ */ new Date()).Format("yyyy-MM-dd hh:mm:ss.S")}]:` + message
    );
    logFileWriteStream.write(content + "\n");
    if (process.env.TUZI_ENV === "app") {
      sendLog(level, message, _block);
    } else {
      olog(content);
    }
  }
  console.log = function() {
    log.call(this, "info", globalThis._block, ...arguments);
  };
  console.debug = function() {
    log.call(this, "debug", globalThis._block, ...arguments);
  };
  console.info = function() {
    log.call(this, "info", globalThis._block, ...arguments);
  };
  console.warn = function() {
    log.call(this, "warn", globalThis._block, ...arguments);
  };
  console.error = function() {
    log.call(this, "error", globalThis._block, ...arguments);
  };
  console["fatalError"] = function() {
    log.call(this, "fatalError", globalThis._block, ...arguments);
  };
  console["runStep"] = function() {
    log.call(this, "debug", globalThis._block, ...arguments);
    const content = {
      level: "info",
      time: Date.now(),
      message: `执行指令${globalThis._block.directiveDisplayName}`,
      data: globalThis._block
    };
    sendStepLog(content);
  };
}
exports.flowModuleImport = flowModuleImport;
exports.getCurApp = getCurApp;
exports.getTuziAppInfo = getTuziAppInfo;
exports.invokeApi = invokeApi;
exports.oerror = oerror;
exports.olog = olog;
exports.sendLog = sendLog;
exports.sendStepLog = sendStepLog;
exports.setLogFile = setLogFile;
exports.typeToCode = typeToCode;
//# sourceMappingURL=commonUtil-BHmQwyGF.js.map
