"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.impl = exports.config = void 0;
const path_1 = require("path");
const fs_1 = __importDefault(require("fs"));
exports.config = {
    name: 'file.getFileList',
    sort: 2,
    displayName: '获取文件列表',
    icon: 'icon-web-create',
    isControl: false,
    isControlEnd: false,
    comment: '获取指定文件夹${fileDir}下，是否递归${isRecursion}获取文件列表，以及是否包含文件夹${isIncludeDir},并将结果保存到变量${fileList}中',
    inputs: {
        fileDir: {
            name: 'fileDir',
            value: '',
            display: '',
            type: 'string',
            addConfig: {
                required: true,
                label: '文件夹目录',
                placeholder: '请输入文件夹目录',
                type: 'filePath',
                openDirectory: true
            }
        },
        isRecursion: {
            name: 'isRecursion',
            value: '',
            display: '',
            type: 'string',
            addConfig: {
                label: '是否递归文件夹',
                placeholder: '是否递归文件夹 (是/否) 默认为是',
                type: 'string',
                defaultValue: '是'
            }
        },
        isIncludeDir: {
            name: 'isIncludeDir',
            value: '',
            display: '',
            type: 'string',
            addConfig: {
                label: '是否包含文件夹',
                placeholder: '是否包含文件夹 (是/否) 默认为否',
                type: 'string',
                defaultValue: '否'
            }
        }
    },
    outputs: {
        fileList: {
            name: '',
            display: '文件列表',
            type: 'array',
            addConfig: {
                required: true,
                label: '文件列表',
                defaultValue: 'fileList',
                type: 'variable'
            }
        }
    }
};
const impl = function (_a) {
    return __awaiter(this, arguments, void 0, function* ({ fileDir, isRecursion, isIncludeDir }) {
        isRecursion = (isRecursion === null || isRecursion === void 0 ? void 0 : isRecursion.trim()) || '是';
        isIncludeDir = (isIncludeDir === null || isIncludeDir === void 0 ? void 0 : isIncludeDir.trim()) || '否';
        const isRecursionBool = isRecursion.toLocaleLowerCase() === '是';
        const isIncludeDirBool = isIncludeDir.toLocaleLowerCase() === '是';
        const files = fs_1.default.readdirSync(fileDir, {
            withFileTypes: true,
            recursive: isRecursionBool
        });
        const fileList = files
            .filter((file) => (file.isDirectory() && isIncludeDirBool) || file.isFile())
            .map((file) => (0, path_1.join)(file.parentPath, file.name));
        return { fileList };
    });
};
exports.impl = impl;
