"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.impl = exports.config = void 0;
const config = {
    name: 'web.cssElementClick',
    sort: 2,
    displayName: 'CSS点击元素',
    icon: 'icon-web-create',
    isControl: false,
    isControlEnd: false,
    comment: '在页面对象${browserPage}中获取元素${selector} 并点击，元素超时时间${timeout}秒',
    inputs: {
        browserPage: {
            name: 'browserPage',
            value: '',
            display: '',
            type: 'variable',
            addConfig: {
                label: '网页对象',
                type: 'variable',
                filtersType: 'web.page',
                autoComplete: true
            }
        },
        selector: {
            name: 'selector',
            value: '',
            display: '',
            type: 'string',
            addConfig: {
                required: true,
                label: '元素选择器',
                placeholder: '支持 CSS 例:#id .class 或 xpath 例://div[text()="hello"]',
                elementLibrarySupport: true,
                type: 'textarea'
            }
        },
        timeout: {
            name: 'timeout',
            value: '',
            type: 'number',
            addConfig: {
                isAdvanced: true,
                label: '超时时间',
                type: 'string',
                defaultValue: 30
            }
        }
    },
    outputs: {}
};
exports.config = config;
const impl = function (_a) {
    return __awaiter(this, arguments, void 0, function* ({ browserPage, selector, timeout }) {
        let webElement;
        if (selector.startsWith('//')) {
            selector = `::-p-xpath(${selector})`;
        }
        try {
            if (!browserPage) {
                throw new Error('浏览器页面对象不能为空');
            }
            webElement = yield browserPage.waitForSelector(selector, {
                timeout: timeout * 1000
            });
        }
        catch (error) {
            console.log(error);
            throw new Error(`超时${timeout}秒，未找到元素：${selector}`);
        }
        if (webElement) {
            function tap() {
                return __awaiter(this, arguments, void 0, function* (c = 5) {
                    try {
                        yield (webElement === null || webElement === void 0 ? void 0 : webElement.tap());
                    }
                    catch (error) {
                        if (c > 0) {
                            yield tap(c - 1);
                            return;
                        }
                        yield new Promise((resolve) => setTimeout(resolve, 0.3));
                    }
                });
            }
            yield tap();
        }
        else {
            throw new Error(`未找到元素：${selector}`);
        }
    });
};
exports.impl = impl;
