"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.impl = exports.config = void 0;
exports.config = {
    name: 'web.cssGetElementProperty',
    sort: 2,
    displayName: 'CSS获取元素属性值',
    icon: 'icon-web-create',
    isControl: false,
    isControlEnd: false,
    comment: '在${browserPage}页面中，通过CSS选择器${selector},超时时间${timeout}秒, 获取元素属性${property},并保存到变量${propertyValue}',
    inputs: {
        browserPage: {
            name: 'browserPage',
            value: '',
            display: '',
            type: 'variable',
            addConfig: {
                label: '网页对象',
                type: 'variable',
                filtersType: 'web.page',
                autoComplete: true
            }
        },
        selector: {
            name: 'selector',
            value: '',
            display: '',
            type: 'string',
            addConfig: {
                required: true,
                label: '元素选择器',
                placeholder: '支持 CSS 例:#id .class 或 xpath 例://div[text()="hello"]',
                elementLibrarySupport: true,
                type: 'textarea'
            }
        },
        property: {
            name: 'property',
            value: '',
            display: '文本内容',
            type: 'string',
            addConfig: {
                required: true,
                label: '选择获取的属性',
                type: 'select',
                options: [
                    {
                        label: '文本内容',
                        value: 'innerText'
                    },
                    {
                        label: 'html内容',
                        value: 'innerHTML'
                    },
                    {
                        label: 'src属性',
                        value: 'src'
                    }
                ],
                defaultValue: 'innerText',
                tip: '获取的属性的值'
            }
        },
        timeout: {
            name: 'timeout',
            value: '',
            type: 'number',
            addConfig: {
                isAdvanced: true,
                label: '超时时间',
                type: 'string',
                defaultValue: 30
            }
        }
    },
    outputs: {
        propertyValue: {
            name: 'propertyValue',
            display: '元素属性值',
            type: 'string',
            addConfig: {
                label: '元素属性值',
                type: 'variable',
                defaultValue: ''
            }
        }
    }
};
const impl = function (_a) {
    return __awaiter(this, arguments, void 0, function* ({ browserPage, selector, property, timeout }) {
        if (selector.startsWith('//')) {
            selector = `::-p-xpath(${selector})`;
        }
        try {
            if (!browserPage) {
                throw new Error('浏览器页面对象不能为空');
            }
            const webElement = yield browserPage.waitForSelector(selector, {
                timeout: timeout * 1000
            });
            if (webElement) {
                const propertyValue = yield webElement.getProperty(property);
                return {
                    propertyValue: yield propertyValue.jsonValue()
                };
            }
            return { propertyValue: '' };
        }
        catch (error) {
            console.log(error);
            return { propertyValue: '' };
        }
    });
};
exports.impl = impl;
