"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.impl = exports.config = void 0;
exports.config = {
    name: 'web.http.getResponse',
    sort: 2,
    displayName: '等待获取网页请求结果',
    icon: 'icon-web-create',
    isControl: false,
    isControlEnd: false,
    description: '监听到数据返回时，返回数据 数据包含 url、method、remoteAddress、headers、body、buffer、json 等信息',
    comment: '在网页${browserPage}中获取监听请求结果，超时时间为${timeout}秒，结果数据存入${responseData}变量',
    inputs: {
        browserPage: {
            name: 'browserPage',
            value: '',
            display: '',
            type: 'variable',
            addConfig: {
                label: '网页对象',
                type: 'variable',
                filtersType: 'web.page',
                autoComplete: true
            }
        },
        listenerObj: {
            name: 'listenerObj',
            value: '',
            display: '',
            type: 'variable',
            addConfig: {
                label: '网页请求监听对象',
                type: 'variable',
                filtersType: 'web.listenerObj',
                autoComplete: true
            }
        },
        timeout: {
            name: 'timeout',
            value: '30',
            type: 'number',
            addConfig: {
                label: '超时',
                type: 'string',
                required: true,
                defaultValue: '30',
                tip: '超时时间，单位：秒'
            }
        }
    },
    outputs: {
        responseData: {
            name: '',
            display: '请求结果数据',
            type: 'web.listenerObj',
            typeDetails: [
                {
                    key: 'status',
                    display: '状态码',
                    type: 'number'
                },
                {
                    key: 'url',
                    display: '请求地址',
                    type: 'string'
                },
                {
                    key: 'remoteAddress',
                    display: '远程地址',
                    type: 'string'
                },
                {
                    key: 'headers',
                    display: '请求头',
                    type: 'object',
                    typeDetails: [
                        {
                            key: 'content-type',
                            display: '内容类型',
                            type: 'object',
                            typeDetails: [
                                {
                                    key: 'value',
                                    display: '值',
                                    type: 'string'
                                }
                            ]
                        },
                        {
                            key: 'content-length',
                            display: '内容长度',
                            type: 'number'
                        }
                    ]
                },
                {
                    key: 'body',
                    display: '请求体',
                    type: 'string'
                },
                {
                    key: 'buffer',
                    display: '请求数据',
                    type: 'buffer'
                }
            ],
            addConfig: {
                label: '请求结果数据',
                type: 'variable',
                defaultValue: '请求结果数据'
            }
        }
    }
};
const impl = function (_a) {
    return __awaiter(this, arguments, void 0, function* ({ browserPage, listenerObj, timeout }) {
        const startTime = Date.now();
        let resData;
        listenerObj.responsePromise
            .then((res) => {
            resData = res;
        })
            .catch((err) => {
            throw new Error(err);
        })
            .finally(() => {
            browserPage === null || browserPage === void 0 ? void 0 : browserPage.off('response', listenerObj.responseListener);
        });
        const endTime = startTime + timeout * 1000;
        while (endTime > Date.now()) {
            if (resData) {
                const url = resData === null || resData === void 0 ? void 0 : resData.url();
                const body = yield (resData === null || resData === void 0 ? void 0 : resData.text());
                const remoteAddress = yield (resData === null || resData === void 0 ? void 0 : resData.remoteAddress());
                const status = yield (resData === null || resData === void 0 ? void 0 : resData.status());
                const headers = yield (resData === null || resData === void 0 ? void 0 : resData.headers());
                const buffer = yield (resData === null || resData === void 0 ? void 0 : resData.buffer());
                const responseData = {
                    status,
                    url,
                    remoteAddress,
                    headers,
                    body,
                    buffer
                };
                return { responseData };
            }
            yield new Promise((resolve) => setTimeout(resolve, 100));
        }
        throw new Error('获取网页请求结果超时');
    });
};
exports.impl = impl;
