"use strict";
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.impl = exports.config = void 0;
exports.config = {
    name: 'web.pageElementScroll',
    displayName: '页面元素滚动',
    icon: 'icon-web-create',
    isControl: false,
    isControlEnd: false,
    comment: '元素${element}滚动到底部，每次滚动${scrollDistance}，延迟${scrollDelay}毫秒',
    inputs: {
        element: {
            name: 'element',
            value: '',
            display: '',
            type: 'variable',
            addConfig: {
                label: '页面元素对象',
                type: 'variable',
                filtersType: 'web.Element',
                autoComplete: true
            }
        },
        scrollDistance: {
            name: 'scrollDistance',
            value: '100',
            display: '每次滚动距离',
            type: 'number',
            addConfig: {
                label: '每次滚动距离',
                type: 'variable',
                autoComplete: true,
                required: true,
                defaultValue: '100'
            }
        },
        scrollDelay: {
            name: 'scrollDelay',
            value: '600',
            display: '滚动延迟',
            type: 'number',
            addConfig: {
                label: '滚动延迟',
                type: 'variable',
                autoComplete: true,
                required: true,
                defaultValue: '600'
            }
        }
    },
    outputs: {}
};
const impl = function (_a) {
    return __awaiter(this, arguments, void 0, function* ({ element, scrollDistance, scrollDelay }) {
        // 获取元素的总高度
        let pageHeight = yield element.evaluate((el) => el.scrollHeight);
        let currentPosition = 0;
        while (currentPosition < pageHeight) {
            // 滚动页面
            yield element.evaluate((el, scrollDistance) => {
                el.scrollBy({
                    left: 0,
                    top: scrollDistance,
                    behavior: 'smooth'
                });
            }, scrollDistance);
            currentPosition += scrollDistance;
            pageHeight = yield element.evaluate((el) => el.scrollHeight);
            console.log('元素滚动中...', `currentPosition: ${currentPosition}, pageHeight: ${pageHeight}`);
            // 等待一段时间再进行下一次滚动
            yield new Promise((resolve) => setTimeout(resolve, scrollDelay));
        }
    });
};
exports.impl = impl;
